DoctorViolation class

Constructors

DoctorViolation({required String filePath, required int lineNumber, required String sourceLayer, required String targetLayer, required String importUri, required String description})

Properties

description → String
final
filePath → String
final
hashCode → int
The hash code for this object.
no setterinherited
importUri → String
final
lineNumber → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceLayer → String
final
targetLayer → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited