ZuqCli class

Constructors

ZuqCli({Logger? logger})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runner → CommandRunner<int>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run(List<String> args) → Future<int>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited