ProjectConfig class

Constructors

ProjectConfig({required String projectName, required String stateManagement, required String router, required String preset, required List<String> modules})
ProjectConfig.fromMap(Map<String, dynamic> map, {required String defaultName})
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
modules List<String>
final
preset String
final
projectName String
final
router String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stateManagement String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited