ProjectContext class

Constructors

ProjectContext({required String projectName, required String projectPath, required String stateManagement, required String router})

Properties

corePackages → List<String>
final
devPackages → List<String>
final
hashCode → int
The hash code for this object.
no setterinherited
libPath → String
no setter
projectName → String
final
projectPath → String
final
router → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stateManagement → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited