DependencyResolver class

Constructors

DependencyResolver()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addNode(String id, List<String> dependencies) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(List<String> requestedIds, List<String> installedIds) List<String>
Resolves the topological install order for the requestedIds, filtering out any modules that are already inside installedIds.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited