TemplateGenerator class

Constructors

TemplateGenerator()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

generateFeature({required String targetDirectory, required String featureName}) → Future<void>
generateProjectCore({required String projectPath, required String projectName, required bool isRiverpod, required bool isBloc, required bool isProvider, required bool isNone, required bool isGoRouter, required bool isAutoRoute}) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited