ProjectGenerator class
Constructors
- ProjectGenerator({DirectoryGenerator directoryGenerator = const DirectoryGenerator(), TemplateGenerator templateGenerator = const TemplateGenerator(), ProcessRunner processRunner = const ProcessRunner(), Logger? logger})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
generate(
{required String projectName, required String stateManagement, required String router, String preset = 'default', List< String> platforms = const []}) → Future<int> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited